from fmcapi.api_objects.apiclasstemplate import APIClassTemplate
import logging


class TunnelStatuses(APIClassTemplate):
    """The TunnelStatuses Object in the FMC."""

    FIRST_SUPPORTED_FMC_VERSION = "7.3"
    VALID_JSON_DATA = [
        "id",
        "type",
        "state",
        "lastChange",
        "vpnTopology",
        "peerA",
        "peerB",
    ]
    VALID_GET_FILTERS = [
        "vpnTopologyId",  # vpnTopologyId: uuid of vpn topo
        "deviceId",  # deviceId: uuid of device
        "status",  # status: TUNNEL_UP|TUNNEL_DOWN|UNKNOWN
        "deployedStatus",  # deployedStatus: Deployed|Configured|Both
        "sortBy",  # sortBy: :|<|> Topology|Device|Status|LastChange (sortBy<Device == sort by device in ascending order)
    ]
    VALID_FOR_KWARGS = VALID_JSON_DATA + VALID_GET_FILTERS + []

    URL_SUFFIX = "/health/tunnelstatuses"

    def __init__(self, fmc, **kwargs):
        """
        Initialize TunnelStatuses object.

        :param fmc (object): FMC object
        :param **kwargs: Any other values passed during instantiation.
        :return: requests response
        """
        super().__init__(fmc, **kwargs)
        logging.debug("In __init__() for TunnelStatuses class.")
        self.parse_kwargs(**kwargs)

    def delete(self, **kwargs):
        """DELETE method for API for TunnelStatuses not supported."""
        logging.info("DELETE method for API for TunnelStatuses not supported.")
        pass

    def put(self):
        """PUT method for API for TunnelStatuses not supported."""
        logging.info("PUT method for API for TunnelStatuses not supported.")
        pass

    def post(self, **kwargs):
        """POST method for API for TunnelStatuses not supported."""
        logging.info("POST method for API for TunnelStatuses not supported.")
        pass



import logging
import fmcapi


def test__metrics(fmc):
    logging.info("Test Metrics.  Get Metrics.")

    obj1 = fmcapi.Metrics(fmc=fmc)
    metrics = obj1.get(
        deviceUUIDs="6255c614-352f-11ee-ab63-aead54c9541f",
        metric="vpn",
        startTime=1747228084,
        endTime=1747228084,
        step=1
    )
    del(obj1)

    logging.info("Test Metrics done.\n")


import logging
import fmcapi


def test__alerts(fmc):
    logging.info("Test Alerts.  Get Alerts.")

    obj1 = fmcapi.Alerts(fmc=fmc)
    alerts = obj1.get()
    del(obj1)

    logging.info("Test Alerts done.\n")


import logging
import fmcapi


def test__tunneldetails(fmc):
    logging.info("Test TunnelDetails.  Get TunnelDetails.")

    obj1 = fmcapi.TunnelDetails(fmc=fmc, container_uuid="40A6B737-FDDC-0ed3-0000-000000000297") # Tunnel uuid not topology uuid
    tunnel_details = obj1.get()
    del obj1

    logging.info("Test TunnelDetails done.\n")


from fmcapi.api_objects.apiclasstemplate import APIClassTemplate
import logging


class Metrics(APIClassTemplate):
    """The Metrics Object in the FMC."""

    FIRST_SUPPORTED_FMC_VERSION = "7.3"
    VALID_JSON_DATA = [
        "deviceUUID",
        "type",
        "metric",
    ]
    VALID_GET_FILTERS = [
        "deviceUUIDs",
        "metric",
        "startTime",
        "endTime",
        "step",
        "regexFilter",
        "queryFunction",
        "rateFunctionInterval",
    ]

    REQUIRED_GET_FILTERS = ["metric", "startTime", "endTime", "step"]

    VALID_FOR_KWARGS = VALID_JSON_DATA + VALID_GET_FILTERS + []

    URL_SUFFIX = "/health/metrics"

    def __init__(self, fmc, **kwargs):
        """
        Initialize Metrics object.

        :param fmc (object): FMC object
        :param **kwargs: Any other values passed during instantiation.
        :return: requests response
        """
        super().__init__(fmc, **kwargs)
        logging.debug("In __init__() for Metrics class.")
        self.parse_kwargs(**kwargs)

    def get(self, **kwargs):
        """
        Prepare to send GET call to retrieve Prometheus Health Metrics from FMC.

        :param: metric=Required name of the prometheus metric to be queried[cpu, mem, interface, asp_drops, vpn, etc.]
        :param: startTime=Required start time in unix format seconds
        :param: endTime=Required end time in unix format seconds
        :param: step=Required step interval in seconds over which the data is returned
        :param: deviceUUIDs=Optional List UUID of the device to be queried.
        :param: regexFilter=Optional filter to be applied on the metric names[snort.*|lina.*]
        :param: queryFunction=Optional query function which has to be applied to the query[avg, rate, min, max]
        :param: rateFunctionInterval=Optional interval which has to be applied to the rate function[1m, 5m, etc.]
        :return: requests response
        """
        logging.debug("In get() for Metrics class.")

        return super().get(**kwargs)

    def delete(self, **kwargs):
        """DELETE method for API for Metrics not supported."""
        logging.info("DELETE method for API for Metrics not supported.")
        pass

    def put(self):
        """PUT method for API for Metrics not supported."""
        logging.info("PUT method for API for Metrics not supported.")
        pass

    def post(self, **kwargs):
        """POST method for API for Metrics not supported."""
        logging.info("POST method for API for Metrics not supported.")
        pass



import logging
import fmcapi


def test__events(fmc):
    logging.info("Test Events.  Get Events.")

    obj1 = fmcapi.Events(fmc=fmc)
    events = obj1.get()
    del(obj1)

    logging.info("Test Events done.\n")


import logging
import fmcapi


def test__tunnelstatuses(fmc):
    logging.info("Test TunnelStatuses.  Get TunnelStatuses.")

    obj1 = fmcapi.TunnelStatuses(fmc=fmc)
    all_tunnel_statuses = obj1.get()
    del(obj1)

    obj2 = fmcapi.TunnelStatuses(fmc=fmc)
    obj2.id = "40A6B737-FDDC-0ed3-0000-000000000297"
    id_tunnel_status = obj2.get()
    del(obj2)

    logging.info("Test TunnelStatuses done.\n")


"""Health Classes."""

import logging
from .terminateravpnsessions import TerminateRAVPNSessions
from .tunnelstatuses import TunnelStatuses
from .tunneldetails import TunnelDetails
from .tunnelsummaries import TunnelSummaries
from .metrics import Metrics
from .alerts import Alerts
from .events import Events

logging.debug("In the health __init__.py file.")

__all__ = ["Health"]



from fmcapi.api_objects.apiclasstemplate import APIClassTemplate
import logging


class Alerts(APIClassTemplate):
    """The Alerts Object in the FMC."""

    FIRST_SUPPORTED_FMC_VERSION = "7.3"
    VALID_JSON_DATA = []
    VALID_GET_FILTERS = [
        "deviceUUIDs",
        "startTime",
        "endTime",
        "status",
        "moduleIDs",
    ]

    VALID_FOR_KWARGS = VALID_JSON_DATA + VALID_GET_FILTERS + []

    URL_SUFFIX = "/health/alerts"

    def __init__(self, fmc, **kwargs):
        """
        Initialize Alerts object.

        :param fmc (object): FMC object
        :param **kwargs: Any other values passed during instantiation.
        :return: requests response
        """
        super().__init__(fmc, **kwargs)
        logging.debug("In __init__() for Alerts class.")
        self.parse_kwargs(**kwargs)

    def get(self, **kwargs):
        """
        Prepare to send GET call to retrieve Prometheus Health Alerts from FMC.

        :param: deviceUUIDs=Optional List UUID of the device to be queried.
        :param: startTime=Optional start time in unix format seconds
        :param: endTime=Optional end time in unix format seconds
        :param: status=Optional List of status codes to filter delimited by comma, e.g. green,red,yellow.
        :param: moduleIDs=Optional List of module ids to filter, delimited by comma.
        :return: requests response
        """
        logging.debug("In get() for Alerts class.")

        return super().get(**kwargs)

    def delete(self, **kwargs):
        """DELETE method for API for Alerts not supported."""
        logging.info("DELETE method for API for Alerts not supported.")
        pass

    def put(self):
        """PUT method for API for Alerts not supported."""
        logging.info("PUT method for API for Alerts not supported.")
        pass

    def post(self, **kwargs):
        """POST method for API for Alerts not supported."""
        logging.info("POST method for API for Alerts not supported.")
        pass



import logging
import fmcapi


def test__tunnelsummaries(fmc):
    logging.info("Test TunnelSummaries.  Get TunnelSummaries.")

    obj1 = fmcapi.TunnelSummaries(fmc=fmc)
    tunnel_summaries = obj1.get()
    del obj1

    logging.info("Test TunnelSummaries done.\n")


from fmcapi.api_objects.apiclasstemplate import APIClassTemplate
import logging


class TunnelDetails(APIClassTemplate):
    """The TunnelDetails Object in the FMC."""

    FIRST_SUPPORTED_FMC_VERSION = "7.3"
    REQUIRED_FOR_GET = ["container_uuid"]
    VALID_JSON_DATA = [
        "type",
        "peerA",
        "peerB",
    ]

    VALID_FOR_KWARGS = VALID_JSON_DATA + ["container_uuid"]

    URL_SUFFIX = f"/health/tunnelstatuses"

    def __init__(self, fmc, **kwargs):
        """
        Initialize TunnelDetails object.

        :param fmc (object): FMC object
        :param **kwargs: Any other values passed during instantiation.
        :return: requests response
        """
        super().__init__(fmc, **kwargs)
        logging.debug("In __init__() for TunnelDetails class.")
        self.parse_kwargs(**kwargs)
        URL_CONTAINER_SUFFIX = f"/{self.container_uuid}/tunneldetails"
        self.URL = self.URL + URL_CONTAINER_SUFFIX

    def delete(self, **kwargs):
        """DELETE method for API for TunnelDetails not supported."""
        logging.info("DELETE method for API for TunnelDetails not supported.")
        pass

    def put(self):
        """PUT method for API for TunnelDetails not supported."""
        logging.info("PUT method for API for TunnelDetails not supported.")
        pass

    def post(self, **kwargs):
        """POST method for API for TunnelDetails not supported."""
        logging.info("POST method for API for TunnelDetails not supported.")
        pass
